@@ -6,15 +6,15 @@ from typing import Optional, AsyncGenerator, Union, Callable
 
 from aioscrapy import Spider
 from aioscrapy import signals
+from aioscrapy.core.downloader import DownloaderTV
+from aioscrapy.core.scheduler import BaseScheduler
+from aioscrapy.core.scraper import Scraper
 from aioscrapy.exceptions import DontCloseSpider
 from aioscrapy.http import Response
 from aioscrapy.http.request import Request
 from aioscrapy.utils.log import logformatter_adapter
 from aioscrapy.utils.misc import load_instance
 from aioscrapy.utils.tools import call_helper
-from aioscrapy.core.downloader import DownloaderTV
-from aioscrapy.core.scheduler import BaseScheduler
-from aioscrapy.core.scraper import Scraper
 
 logger = logging.getLogger(__name__)
 
@@ -64,10 +64,10 @@ class ExecutionEngine(object):
         await self.signals.send_catch_log_deferred(signal=signals.engine_started)
         await self.open(spider, start_requests)
         while not self.finish:
-            self.running and asyncio.create_task(self._next_request())
+            self.running and await self._next_request()
             await asyncio.sleep(1)
 
-    async def stop(self) -> None:
+    async def stop(self, reason: str = 'shutdown') -> None:
         """Stop the execution engine gracefully"""
         if not self.running:
             raise RuntimeError("Engine not running")
@@ -75,7 +75,7 @@ class ExecutionEngine(object):
 
         while not await self.is_idle():
             await asyncio.sleep(0.2)
-        await self.close_spider(self.spider, reason='shutdown')
+        await self.close_spider(self.spider, reason=reason)
         await self.signals.send_catch_log_deferred(signal=signals.engine_stopped)
         self.finish = True
 
@@ -88,6 +88,7 @@ class ExecutionEngine(object):
 
         self.spider = spider
         await call_helper(self.crawler.stats.open_spider, spider)
+
         self.scheduler = await load_instance(self.settings['SCHEDULER'], crawler=self.crawler)
         self.downloader = await load_instance(self.settings['DOWNLOADER'], crawler=self.crawler)
         self.scraper = await call_helper(Scraper.from_crawler, self.crawler)
@@ -137,7 +138,7 @@ class ExecutionEngine(object):
                 self.slot.start_requests = None
                 logger.error('Error while obtaining start requests', exc_info=e, extra={'spider': self.spider})
             else:
-                request and await self.crawl(request, self.spider) and asyncio.create_task(self._next_request())
+                request and asyncio.create_task(self.crawl(request))
             finally:
                 self.slot.lock = False
 
@@ -152,9 +153,12 @@ class ExecutionEngine(object):
         )
 
     async def handle_downloader_output(
-            self, result: Union[Request, Response, BaseException], request: Request
+            self, result: Union[Request, Response, BaseException, None], request: Request
     ) -> None:
         try:
+            if result is None:
+                return
+
             if not isinstance(result, (Request, Response, BaseException)):
                 raise TypeError(
                     "Incorrect type: expected Request, Response or Failure, got %s: %r"
@@ -162,7 +166,7 @@ class ExecutionEngine(object):
                 )
 
             if isinstance(result, Request):
-                await self.crawl(result, self.spider)
+                await self.crawl(result)
                 return
 
             if isinstance(result, Response):
@@ -194,10 +198,12 @@ class ExecutionEngine(object):
 
         return True
 
-    async def crawl(self, request: Request, spider: Optional[Spider] = None) -> None:
-        await self.signals.send_catch_log(signals.request_scheduled, request=request, spider=spider)
+    async def crawl(self, request: Request) -> None:
+        await self.signals.send_catch_log(signals.request_scheduled, request=request, spider=self.spider)
         if not await call_helper(self.scheduler.enqueue_request, request):
-            await self.signals.send_catch_log(signals.request_dropped, request=request, spider=spider)
+            await self.signals.send_catch_log(signals.request_dropped, request=request, spider=self.spider)
+        else:
+            await self._next_request()
 
     async def close_spider(self, spider: Spider, reason: str = 'cancelled') -> None:
         """Close (cancel) spider and clear all its outstanding requests"""
@@ -248,4 +254,4 @@ class ExecutionEngine(object):
                 and self.slot.start_requests is None \
                 and not await self.scheduler.has_pending_requests() \
                 and await self.is_idle():
-            await self.close_spider(spider, reason='finished')
+            await self.stop(reason='finished')
