@@ -2,7 +2,7 @@ from abc import abstractmethod
 from typing import Optional, Type, TypeVar
 
 from aioscrapy import Spider
-from aioscrapy.dupefilters import AbsDupeFilterBase
+from aioscrapy.dupefilters import DupeFilterBase
 from aioscrapy.http.request import Request
 from aioscrapy.queue import AbsQueue
 from aioscrapy.statscollectors import StatsCollector
@@ -88,29 +88,24 @@ class Scheduler(BaseScheduler):
             self,
             queue: AbsQueue,
             spider: Spider,
-            df=Optional[AbsDupeFilterBase],
             stats=Optional[StatsCollector],
             persist: bool = True
     ):
         self.queue = queue
         self.spider = spider
-        self.df = df
         self.stats = stats
         self.persist = persist
 
     @classmethod
     async def from_crawler(cls: Type[SchedulerTV], crawler) -> SchedulerTV:
-        settings = crawler.settings
         instance = cls(
-            await load_instance(settings['SCHEDULER_QUEUE_CLASS'], spider=crawler.spider),
+            await load_instance(crawler.settings['SCHEDULER_QUEUE_CLASS'], spider=crawler.spider),
             crawler.spider,
-            df=settings.get('DUPEFILTER_CLASS') and await load_instance(settings['DUPEFILTER_CLASS'],
-                                                                        spider=crawler.spider),
             stats=crawler.stats,
-            persist=settings.getbool('SCHEDULER_PERSIST', True)
+            persist=crawler.settings.getbool('SCHEDULER_PERSIST', True)
         )
 
-        if settings.getbool('SCHEDULER_FLUSH_ON_START', False):
+        if crawler.settings.getbool('SCHEDULER_FLUSH_ON_START', False):
             await instance.flush()
 
         count = await call_helper(instance.queue.len)
@@ -121,19 +116,11 @@ class Scheduler(BaseScheduler):
     async def close(self, reason: str) -> None:
         if not self.persist:
             await self.flush()
-        self.df and await call_helper(self.df.close, reason)
 
     async def flush(self) -> None:
-        self.df and await call_helper(self.df.clear)
         await call_helper(self.queue.clear)
 
     async def enqueue_request(self, request: Request) -> bool:
-        if not request.dont_filter \
-                and request.filter_mode == 'IN_QUEUE' \
-                and self.df and await self.df.request_seen(request):
-            self.df.log(request, self.spider)
-            return False
-
         await call_helper(self.queue.push, request)
         if self.stats:
             self.stats.inc_value(self.queue.inc_key, spider=self.spider)
@@ -141,12 +128,6 @@ class Scheduler(BaseScheduler):
 
     async def next_request(self, count: int = 1) -> Optional[Request]:
         async for request in self.queue.pop(count):
-            if request and not request.dont_filter \
-                    and request.filter_mode == 'OUT_QUEUE' \
-                    and self.df and await self.df.request_seen(request):
-                self.df.log(request, self.spider)
-                continue
-
             if request and self.stats:
                 self.stats.inc_value(self.queue.inc_key, spider=self.spider)
             yield request
