@@ -1,45 +1,47 @@
 from abc import ABCMeta, abstractmethod
 
+import aioscrapy.crawler
+
 
 class AbsDBPoolManager(object, metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def _clients(self):
+    def _clients(self) -> dict:
         return {}
 
     @abstractmethod
     async def create(self, alias: str, params: dict):
-        """创建连接池"""
+        """Create pool of connection"""
 
     @abstractmethod
     def get_pool(self, alias: str):
-        """获取指定连接池"""
+        """Get pool named `alias`"""
 
     @abstractmethod
     async def close_all(self):
-        """关闭所有连接池"""
+        """Close all pool"""
 
     @abstractmethod
     async def close(self, alias: str):
-        """关闭指定连接池"""
+        """Close pool named `alias`"""
 
     @abstractmethod
     async def from_dict(self, db_args: dict):
-        """更具dict实例化连接池管理类"""
+        """Create pool with dict"""
 
     @abstractmethod
-    async def from_settings(self, settings: "aioscrapy.settings.Setting"):
-        """更具setting实例化连接池管理类"""
+    async def from_settings(self, settings: "aioscrapy.settings.Settings"):
+        """Create pool with settings"""
 
-    async def from_crawler(self, crawler):
+    async def from_crawler(self, crawler: "aioscrapy.crawler.Crawler"):
         return await self.from_settings(crawler.settings)
 
-    def __call__(self, alias):
+    def __call__(self, alias: str):
         return self.get_pool(alias)
 
-    def __getitem__(self, alias):
+    def __getitem__(self, alias: str):
         return self.get_pool(alias)
 
-    def __getattr__(self, alias):
+    def __getattr__(self, alias: str):
         return self.get_pool(alias)
